@@ -6,6 +6,9 @@ import requests
 from configparser import ConfigParser
 from os.path import join, dirname, isfile, isdir
 
+from keyrings.cryptfile.cryptfile import CryptFileKeyring
+from keyring.errors import PasswordDeleteError
+
 import uuid
 import torch
 from torch.utils import model_zoo
@@ -16,25 +19,24 @@ from .settings import system_info
 from .model_zoo import *  # So loading models does not raise Attribute error
 
 # Load configuration parameters.
-# This includes a simple token authentication encoded in base64
+# These are saved in form of a config file
 config_file = join(dirname(os.path.realpath(__file__)), 'config.ini')  # New .env file
 config = ConfigParser()
 config.read(config_file)
 
+# Secure password vault
+# Saves password in encrypted file
+kr = CryptFileKeyring()
+kr.keyring_key = os.getenv('KEYRING_KEY', 'fedbiomed')
+
 # Create a Logger
 logger = Logger()
 logger.info(system_info())
 
-# Create a requests session
+# Create a requests session over HTTP
 session = requests.Session()
 
 
-def update_config():
-    """Update the configuration file."""
-    with open(config_file, 'w') as cf:
-        config.write(cf)
-
-
 def login(username, password):
     """
     Loging in to the FEDBIONET API.
@@ -45,11 +47,9 @@ def login(username, password):
     session.auth = (username, password)
     res = session.get(ME_URL)
     if res.status_code == 200:
-        "Save token to disk and return user profile data."
-
-        TOKEN = base64.b64encode(f'{username}:{password}'.encode()).decode()
-        config['DEFAULT']['TOKEN'] = TOKEN
-        update_config()
+        "Save password to vault and return user profile data."
+        kr.set_password('fedbionet', 'user', username)
+        kr.set_password('fedbionet', 'password', password)
 
         return res.json()
     elif res.status_code in range(400, 500):
@@ -61,13 +61,17 @@ def login(username, password):
 
 
 def get_auth():
-    TOKEN = config['DEFAULT']['TOKEN']
-    return tuple(base64.b64decode(TOKEN.encode()).decode().split(':'))
+    username = kr.get_password('fedbionet', 'user')
+    password = kr.get_password('fedbionet', 'password')
+    return username, password
 
 
 def logout():
-    config.remove_option('DEFAULT', 'TOKEN')
-    update_config()
+    try:
+        kr.delete_password('fedbionet', 'user')
+        kr.delete_password('fedbionet', 'password')
+    except PasswordDeleteError as e:
+        logger.error(e)
 
 
 def is_logged_in():
@@ -92,7 +96,7 @@ def get_uuid_from_url(url):
 
 def handle_response(res):
     # logger.info(f'Response content: {res.headers}')
-    if res.status_code is 204:
+    if res.status_code == 204:
         logger.info('Request successful. Status code: 204.')
         return {'detail': 'Request successful. Status code: 204.'}
     elif res.status_code in range(200, 300):
